@@ -17,6 +17,7 @@ from typing import (
 )
 
 from redux.basic_types import (
+    NOT_SET,
     Action,
     Args,
     AutoAwait,
@@ -127,13 +128,13 @@ class Autorun(
         else:
             self._func = weakref.ref(func, self.unsubscribe)
         self._is_coroutine = (
-            asyncio.coroutines._is_coroutine  # pyright: ignore [reportAttributeAccessIssue]  # noqa: SLF001
+            asyncio.coroutines._is_coroutine  # type: ignore [reportAttributeAccessIssue]  # noqa: SLF001
             if asyncio.iscoroutinefunction(func) and options.auto_await is False
             else None
         )
         self._options = options
 
-        self._last_selector_result: SelectorOutput | None = None
+        self._last_selector_result: SelectorOutput | None = NOT_SET
         self._last_comparator_result: ComparatorOutput = cast(
             'ComparatorOutput',
             object(),
@@ -230,11 +231,9 @@ class Autorun(
             Args,
             ReturnType,
         ],
-        state: State | None,
+        state: State,
     ) -> bool:
         """Check if the autorun should be called based on the current state."""
-        if state is None:
-            return False
         try:
             selector_result = self._selector(state)
         except AttributeError:
@@ -268,7 +267,7 @@ class Autorun(
     ) -> None:
         """Call the wrapped function with the current state of the store."""
         func = self._func() if isinstance(self._func, weakref.ref) else self._func
-        if func and self._last_selector_result is not None:
+        if func and self._last_selector_result is not NOT_SET:
             value: ReturnType = call_func(
                 func,
                 [self._last_selector_result],
@@ -282,7 +281,7 @@ class Autorun(
                     is False  # only explicit `False` disables auto-await, not `None`
                 ):
                     if (
-                        self._latest_value is not None
+                        self._latest_value is not NOT_SET
                         and isinstance(self._latest_value, AwaitableWrapper)
                         and not self._latest_value.awaited
                     ):
@@ -316,7 +315,7 @@ class Autorun(
         if self._should_be_called or args or kwargs or not self._options.memoization:
             self._should_be_called = False
             self.call(*args, **kwargs)
-        return cast('ReturnType', self._latest_value)
+        return self._latest_value
 
     def __repr__(
         self: Autorun[
@@ -348,7 +347,7 @@ class Autorun(
         ],
     ) -> ReturnType:
         """Get the latest value of the autorun function."""
-        return cast('ReturnType', self._latest_value)
+        return self._latest_value
 
     def subscribe(
         self: Autorun[
@@ -378,7 +377,7 @@ class Autorun(
             callback_ref = weakref.ref(callback)
         self._subscriptions.add(callback_ref)
 
-        if initial_run:
+        if initial_run and self.value is not NOT_SET:
             callback(self.value)
 
         def unsubscribe() -> None:
