@@ -1,4 +1,4 @@
-# ruff: noqa: A003, D100, D101, D102, D103, D104, D105, D107
+# ruff: noqa: D100, D101, D102, D103, D107
 from __future__ import annotations
 
 from collections.abc import Awaitable, Callable, Coroutine, Sequence
@@ -9,11 +9,12 @@ from typing import (
     Any,
     Concatenate,
     Generic,
-    Never,
+    Literal,
     ParamSpec,
     Protocol,
     TypeAlias,
     TypeGuard,
+    cast,
     overload,
 )
 
@@ -23,6 +24,8 @@ from typing_extensions import TypeVar
 if TYPE_CHECKING:
     from asyncio import Task
 
+    from redux.autorun import Autorun
+    from redux.side_effect_runner import SideEffectRunner
 
 T = TypeVar('T')
 
@@ -35,6 +38,15 @@ class BaseAction(Immutable): ...
 class BaseEvent(Immutable): ...
 
 
+class InitAction(BaseAction): ...
+
+
+class FinishAction(BaseAction): ...
+
+
+class FinishEvent(BaseEvent): ...
+
+
 # Type variables
 State = TypeVar('State', bound=Immutable | None, infer_variance=True)
 Action = TypeVar('Action', bound=BaseAction | None, infer_variance=True)
@@ -44,9 +56,10 @@ SelectorOutput = TypeVar('SelectorOutput', infer_variance=True)
 ComparatorOutput = TypeVar('ComparatorOutput', infer_variance=True)
 ReturnType = TypeVar('ReturnType', infer_variance=True)
 Comparator = Callable[[State], ComparatorOutput]
-EventHandler = Callable[[Event], Any] | Callable[[], Any]
+EventHandler: TypeAlias = Callable[[Event], Any] | Callable[[], Any]
 Args = ParamSpec('Args')
 Payload = TypeVar('Payload', bound=Any, default=None)
+MethodSelf = TypeVar('MethodSelf', bound=object, infer_variance=True)
 
 
 class CompleteReducerResult(Immutable, Generic[State, Action, Event]):
@@ -55,8 +68,11 @@ class CompleteReducerResult(Immutable, Generic[State, Action, Event]):
     events: Sequence[Event] | None = None
 
 
-ReducerResult = CompleteReducerResult[State, Action, Event] | State
-ReducerType = Callable[[State | None, Action], ReducerResult[State, Action, Event]]
+ReducerResult: TypeAlias = CompleteReducerResult[State, Action, Event] | State
+ReducerType: TypeAlias = Callable[
+    [State | None, Action],
+    ReducerResult[State, Action, Event],
+]
 
 
 class InitializationActionError(Exception):
@@ -67,15 +83,6 @@ action "{action}" is not allowed.""",
         )
 
 
-class InitAction(BaseAction): ...
-
-
-class FinishAction(BaseAction): ...
-
-
-class FinishEvent(BaseEvent): ...
-
-
 def is_complete_reducer_result(
     result: ReducerResult[State, Action, Event],
 ) -> TypeGuard[CompleteReducerResult[State, Action, Event]]:
@@ -100,8 +107,6 @@ class TaskCreator(Protocol):
     def __call__(
         self: TaskCreator,
         coro: Coroutine,
-        *,
-        callback: TaskCreatorCallback | None = None,
     ) -> None: ...
 
 
@@ -113,23 +118,110 @@ class EventMiddleware(Protocol, Generic[Event]):
     def __call__(self: EventMiddleware, event: Event) -> Event | None: ...
 
 
-class CreateStoreOptions(Immutable, Generic[Action, Event]):
+class StoreOptions(Immutable, Generic[Action, Event]):
     auto_init: bool = False
-    threads: int = 5
+    side_effect_threads: int = 1
     scheduler: Scheduler | None = None
-    action_middlewares: Sequence[ActionMiddleware[Action]] = field(default_factory=list)
-    event_middlewares: Sequence[EventMiddleware[Event]] = field(default_factory=list)
+    action_middlewares: Sequence[ActionMiddleware[Action | InitAction]] = field(
+        default_factory=list,
+    )
+    event_middlewares: Sequence[EventMiddleware[Event | FinishEvent]] = field(
+        default_factory=list,
+    )
     task_creator: TaskCreator | None = None
     on_finish: Callable[[], Any] | None = None
     grace_time_in_seconds: float = 1
+    autorun_class: type[Autorun] = field(
+        default_factory=lambda: __import__(
+            'redux.autorun',
+            fromlist=['redux'],
+        ).Autorun,
+    )
+    side_effect_runner_class: type[SideEffectRunner] = field(
+        default_factory=lambda: __import__(
+            'redux.side_effect_runner',
+            fromlist=['redux'],
+        ).SideEffectRunner,
+    )
 
 
 # Autorun
 
+AutoAwait = TypeVar(
+    'AutoAwait',
+    bound=(Literal[True, False] | None),
+    infer_variance=True,
+)
 
-class AutorunOptions(Immutable, Generic[ReturnType]):
+NOT_SET = object()
+
+
+class AutorunOptionsType(Immutable, Generic[ReturnType, AutoAwait]):
     default_value: ReturnType | None = None
-    auto_await: bool = True
+    auto_await: AutoAwait = cast('AutoAwait', val=None)
+    initial_call: bool = True
+    reactive: bool = True
+    memoization: bool = True
+    keep_ref: bool = True
+    subscribers_initial_run: bool = True
+    subscribers_keep_ref: bool = True
+
+    @overload
+    def __init__(
+        self: AutorunOptionsType[ReturnType, None],  # type: ignore[reportInvalidTypeVar]
+        *,
+        default_value: ReturnType | None = None,
+        auto_await: None = None,
+        initial_call: bool = True,
+        reactive: bool = True,
+        memoization: bool = True,
+        keep_ref: bool = True,
+        subscribers_initial_run: bool = True,
+        subscribers_keep_ref: bool = True,
+    ) -> None: ...
+    @overload
+    def __init__(
+        self: AutorunOptionsType[ReturnType, Literal[True]],  # type: ignore[reportInvalidTypeVar]
+        *,
+        default_value: ReturnType | None = None,
+        auto_await: Literal[True],
+        initial_call: bool = True,
+        reactive: bool = True,
+        memoization: bool = True,
+        keep_ref: bool = True,
+        subscribers_initial_run: bool = True,
+        subscribers_keep_ref: bool = True,
+    ) -> None: ...
+    @overload
+    def __init__(
+        self: AutorunOptionsType[ReturnType, Literal[False]],  # type: ignore[reportInvalidTypeVar]
+        *,
+        default_value: ReturnType | None = None,
+        auto_await: Literal[False],
+        initial_call: bool = True,
+        reactive: bool = True,
+        memoization: bool = True,
+        keep_ref: bool = True,
+        subscribers_initial_run: bool = True,
+        subscribers_keep_ref: bool = True,
+    ) -> None: ...
+    def __init__(  # noqa: PLR0913
+        self: AutorunOptionsType,
+        *,
+        default_value: ReturnType | None = None,
+        auto_await: bool | None = None,
+        initial_call: bool = True,
+        reactive: bool = True,
+        memoization: bool = True,
+        keep_ref: bool = True,
+        subscribers_initial_run: bool = True,
+        subscribers_keep_ref: bool = True,
+    ) -> None: ...
+
+
+class AutorunOptionsImplementation(Immutable, Generic[ReturnType, AutoAwait]):
+    default_value: ReturnType | None = cast('None', NOT_SET)
+    auto_await: AutoAwait = cast('AutoAwait', val=None)
     initial_call: bool = True
     reactive: bool = True
     memoization: bool = True
@@ -138,13 +230,12 @@ class AutorunOptions(Immutable, Generic[ReturnType]):
     subscribers_keep_ref: bool = True
 
 
-AutorunOptionsWithDefault = AutorunOptions[ReturnType]
-AutorunOptionsWithoutDefault = AutorunOptions[Never]
+AutorunOptions = cast('type[AutorunOptionsType]', AutorunOptionsImplementation)
 
 
 class AutorunReturnType(
     Protocol,
-    Generic[ReturnType, Args],
+    Generic[Args, ReturnType],
 ):
     def __call__(
         self: AutorunReturnType,
@@ -168,34 +259,101 @@ class AutorunReturnType(
     __name__: str
 
 
-class AutorunDecorator(Protocol, Generic[SelectorOutput, ReturnType]):
+class MethodAutorunReturnType(
+    AutorunReturnType,
+    Protocol,
+    Generic[MethodSelf, Args, ReturnType],
+):
+    def __call__(
+        self: AutorunReturnType,
+        self_: MethodSelf,
+        *args: Args.args,
+        **kwargs: Args.kwargs,
+    ) -> ReturnType: ...
+
+
+class AutorunDecorator(Protocol, Generic[ReturnType, SelectorOutput, AutoAwait]):
     @overload
     def __call__(
-        self: AutorunDecorator,
+        self: AutorunDecorator[ReturnType, SelectorOutput, None],
+        func: Callable[Concatenate[SelectorOutput, Args], Awaitable[ReturnType]],
+    ) -> AutorunReturnType[Args, None]: ...
+    @overload
+    def __call__(
+        self: AutorunDecorator[ReturnType, SelectorOutput, None],
+        func: Callable[
+            Concatenate[MethodSelf, SelectorOutput, Args],
+            Awaitable[ReturnType],
+        ],
+    ) -> MethodAutorunReturnType[MethodSelf, Args, None]: ...
+
+    @overload
+    def __call__(
+        self: AutorunDecorator[ReturnType, SelectorOutput, None],
         func: Callable[
             Concatenate[SelectorOutput, Args],
             ReturnType,
         ],
-    ) -> AutorunReturnType[ReturnType, Args]: ...
+    ) -> AutorunReturnType[Args, ReturnType]: ...
+    @overload
+    def __call__(
+        self: AutorunDecorator[ReturnType, SelectorOutput, None],
+        func: Callable[
+            Concatenate[MethodSelf, SelectorOutput, Args],
+            ReturnType,
+        ],
+    ) -> MethodAutorunReturnType[MethodSelf, Args, ReturnType]: ...
 
     @overload
     def __call__(
-        self: AutorunDecorator,
+        self: AutorunDecorator[ReturnType, SelectorOutput, Literal[True]],
         func: Callable[
             Concatenate[SelectorOutput, Args],
             Awaitable[ReturnType],
         ],
-    ) -> AutorunReturnType[Awaitable[ReturnType], Args]: ...
-
-
-class UnknownAutorunDecorator(Protocol, Generic[SelectorOutput]):
+    ) -> AutorunReturnType[Args, None]: ...
+    @overload
     def __call__(
-        self: UnknownAutorunDecorator,
+        self: AutorunDecorator[ReturnType, SelectorOutput, Literal[True]],
+        func: Callable[
+            Concatenate[MethodSelf, SelectorOutput, Args],
+            Awaitable[ReturnType],
+        ],
+    ) -> MethodAutorunReturnType[MethodSelf, Args, None]: ...
+
+    @overload
+    def __call__(
+        self: AutorunDecorator[ReturnType, SelectorOutput, Literal[False]],
+        func: Callable[
+            Concatenate[SelectorOutput, Args],
+            Awaitable[ReturnType],
+        ],
+    ) -> AutorunReturnType[Args, Awaitable[ReturnType]]: ...
+    @overload
+    def __call__(
+        self: AutorunDecorator[ReturnType, SelectorOutput, Literal[False]],
+        func: Callable[
+            Concatenate[MethodSelf, SelectorOutput, Args],
+            Awaitable[ReturnType],
+        ],
+    ) -> MethodAutorunReturnType[MethodSelf, Args, Awaitable[ReturnType]]: ...
+
+    @overload
+    def __call__(
+        self: AutorunDecorator[ReturnType, SelectorOutput, bool],
         func: Callable[
             Concatenate[SelectorOutput, Args],
             ReturnType,
         ],
-    ) -> AutorunReturnType[ReturnType, Args]: ...
+    ) -> AutorunReturnType[Args, ReturnType]: ...
+    @overload
+    def __call__(
+        self: AutorunDecorator[ReturnType, SelectorOutput, bool],
+        func: Callable[
+            Concatenate[MethodSelf, SelectorOutput, Args],
+            ReturnType,
+        ],
+    ) -> MethodAutorunReturnType[MethodSelf, Args, ReturnType]: ...
 
 
 # View
@@ -209,10 +367,6 @@ class ViewOptions(Immutable, Generic[ReturnType]):
     subscribers_keep_ref: bool = True
 
 
-ViewOptionsWithDefault = ViewOptions[ReturnType]
-ViewOptionsWithoutDefault = ViewOptions[Never]
-
-
 class ViewReturnType(
     Protocol,
     Generic[ReturnType, Args],
@@ -239,17 +393,8 @@ class ViewReturnType(
 
 class ViewDecorator(
     Protocol,
-    Generic[SelectorOutput, ReturnType],
+    Generic[ReturnType, SelectorOutput],
 ):
-    @overload
-    def __call__(
-        self: ViewDecorator,
-        func: Callable[
-            Concatenate[SelectorOutput, Args],
-            ReturnType,
-        ],
-    ) -> ViewReturnType[ReturnType, Args]: ...
-
     @overload
     def __call__(
         self: ViewDecorator,
@@ -258,16 +403,31 @@ class ViewDecorator(
             Awaitable[ReturnType],
         ],
     ) -> ViewReturnType[Awaitable[ReturnType], Args]: ...
-
-
-class UnknownViewDecorator(Protocol, Generic[SelectorOutput]):
+    @overload
     def __call__(
-        self: UnknownViewDecorator,
+        self: ViewDecorator,
+        func: Callable[
+            Concatenate[MethodSelf, SelectorOutput, Args],
+            Awaitable[ReturnType],
+        ],
+    ) -> ViewReturnType[Awaitable[ReturnType], Args]: ...
+
+    @overload
+    def __call__(
+        self: ViewDecorator,
         func: Callable[
             Concatenate[SelectorOutput, Args],
             ReturnType,
         ],
     ) -> ViewReturnType[ReturnType, Args]: ...
+    @overload
+    def __call__(
+        self: ViewDecorator,
+        func: Callable[
+            Concatenate[MethodSelf, SelectorOutput, Args],
+            ReturnType,
+        ],
+    ) -> ViewReturnType[ReturnType, Args]: ...
 
 
 # With Store
@@ -277,11 +437,18 @@ class WithStateDecorator(
     Protocol,
     Generic[SelectorOutput],
 ):
+    @overload
     def __call__(
         self: WithStateDecorator,
         func: Callable[Concatenate[SelectorOutput, Args], ReturnType],
     ) -> Callable[Args, ReturnType]: ...
 
+    @overload
+    def __call__(
+        self: WithStateDecorator,
+        func: Callable[Concatenate[MethodSelf, SelectorOutput, Args], ReturnType],
+    ) -> Callable[Concatenate[MethodSelf, Args], ReturnType]: ...
+
 
 class EventSubscriber(Protocol):
     def __call__(
@@ -293,7 +460,7 @@ class EventSubscriber(Protocol):
     ) -> Callable[[], None]: ...
 
 
-DispatchParameters: TypeAlias = Action | list[Action]
+DispatchParameters: TypeAlias = Action | InitAction | list[Action | InitAction]
 
 
 class Dispatch(Protocol, Generic[State, Action, Event]):
@@ -306,11 +473,11 @@ class Dispatch(Protocol, Generic[State, Action, Event]):
 
 
 class BaseCombineReducerState(Immutable):
-    _id: str
+    combine_reducers_id: str
 
 
 class CombineReducerAction(BaseAction):
-    _id: str
+    combine_reducers_id: str
 
 
 class CombineReducerInitAction(CombineReducerAction, InitAction, Generic[Payload]):
