@@ -3,8 +3,10 @@
 from __future__ import annotations
 
 import asyncio
+import contextlib
 import inspect
 import queue
+import time
 import weakref
 from collections import defaultdict
 from collections.abc import Awaitable, Iterable, Sequence
@@ -62,7 +64,7 @@ if TYPE_CHECKING:
     from collections.abc import Callable
 
 
-class Store(Generic[State, Action, Event], SerializationMixin):
+class Store(SerializationMixin, Generic[State, Action, Event]):
     """Redux store for managing state and side effects."""
 
     def __init__(
@@ -119,19 +121,11 @@ class Store(Generic[State, Action, Event], SerializationMixin):
 
     def _call_listeners(self: Store[State, Action, Event], state: State) -> None:
         for listener_ in self._listeners.copy():
-            if isinstance(listener_, weakref.ref):
-                listener = listener_()
-                if listener is None:
-                    msg = (
-                        'Listener has been garbage collected. '
-                        'Consider using `keep_ref=True` if it suits your use case.'
-                    )
-                    raise RuntimeError(msg)
-            else:
-                listener = listener_
-            result = listener(state)
-            if asyncio.iscoroutine(result) and self.store_options.task_creator:
-                self.store_options.task_creator(result)
+            listener = listener_() if isinstance(listener_, weakref.ref) else listener_
+            if listener is not None:
+                result = listener(state)
+                if asyncio.iscoroutine(result) and self.store_options.task_creator:
+                    self.store_options.task_creator(result)
 
     def _run_actions(self: Store[State, Action, Event]) -> None:
         while len(self._actions) > 0:
@@ -247,7 +241,8 @@ class Store(Generic[State, Action, Event], SerializationMixin):
         """Subscribe to state changes."""
 
         def unsubscribe(_: weakref.ref | None = None) -> None:
-            return self._listeners.remove(listener_ref)
+            with contextlib.suppress(KeyError):
+                self._listeners.remove(listener_ref)
 
         if keep_ref:
             listener_ref = listener
@@ -268,24 +263,23 @@ class Store(Generic[State, Action, Event], SerializationMixin):
         keep_ref: bool = True,
     ) -> SubscribeEventCleanup:
         """Subscribe to events."""
+
+        def unsubscribe(_: weakref.ref | None = None) -> None:
+            self._event_handlers[cast('Event', event_type)].discard(handler_ref)
+
         if keep_ref:
             handler_ref = handler
         elif inspect.ismethod(handler):
-            handler_ref = weakref.WeakMethod(handler)
+            handler_ref = weakref.WeakMethod(handler, unsubscribe)
         else:
-            handler_ref = weakref.ref(handler)
+            handler_ref = weakref.ref(handler, unsubscribe)
 
         self._event_handlers[cast('Event', event_type)].add(handler_ref)
 
-        def unsubscribe() -> None:
-            self._event_handlers[cast('Event', event_type)].discard(handler_ref)
-
         return SubscribeEventCleanup(unsubscribe=unsubscribe, handler=handler)
 
     def _wait_for_store_to_finish(self: Store[State, Action, Event]) -> None:
         """Wait for the store to finish."""
-        import time
-
         while True:
             if (
                 self._actions == []
@@ -439,7 +433,7 @@ class Store(Generic[State, Action, Event], SerializationMixin):
 
             signature = signature_without_selector(func)
             wrapped = wraps(cast('Any', func))(wrapper)
-            wrapped.__signature__ = signature  # pyright: ignore [reportAttributeAccessIssue]
+            wrapped.__signature__ = signature  # type: ignore [reportAttributeAccessIssue]
 
             return wrapped
 
